@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
-#ifndef POWERMANAGEMENTINTERFACE_H
-#define POWERMANAGEMENTINTERFACE_H
+#pragma once
 
 #include <QObject>
 
@@ -16,22 +15,15 @@ class PowerManagementInterfacePrivate;
 
 class PowerManagementInterface : public QObject
 {
-
     Q_OBJECT
 
     Q_PROPERTY(QString reason READ reason WRITE setReason)
 
-    Q_PROPERTY(bool preventSleep
-               READ preventSleep
-               WRITE setPreventSleep
-               NOTIFY preventSleepChanged)
+    Q_PROPERTY(bool preventSleep READ preventSleep WRITE setPreventSleep NOTIFY preventSleepChanged)
 
-    Q_PROPERTY(bool sleepInhibited
-               READ sleepInhibited
-               NOTIFY sleepInhibitedChanged)
+    Q_PROPERTY(bool sleepInhibited READ sleepInhibited NOTIFY sleepInhibitedChanged)
 
 public:
-
     explicit PowerManagementInterface(QObject *parent = nullptr);
 
     ~PowerManagementInterface() override;
@@ -64,13 +56,9 @@ private Q_SLOTS:
     void uninhibitDBusCallFinished(QDBusPendingCallWatcher *aWatcher);
 
 private:
-
     void inhibitSleep();
 
     void uninhibitSleep();
 
     std::unique_ptr<PowerManagementInterfacePrivate> d;
-
 };
-
-#endif // POWERMANAGEMENTINTERFACE_H
