@@ -40,7 +40,13 @@ DiscoverSettings *Updates::discoverSettings() const
 
 bool Updates::mandatoryRebootAfterUpdate() const
 {
-    return UPDATE_NEEDS_REBOOT;
+#if defined WITH_SYSUPDATE_BACKEND
+    return true;
+#elif defined WITH_OSTREE_BACKEND
+    return QFile::exists(QStringLiteral("/run/ostree-booted"));
+#else
+    return false;
+#endif
 }
 
 #include "moc_updates.cpp"
