@@ -41,7 +41,6 @@ DummyBackend::DummyBackend(QObject *parent)
     if (!m_fetching)
         m_reviews->initialize();
 
-    m_updater->setErrorMessage(QStringLiteral("I am super broken"));
     SourcesModel::global()->addSourcesBackend(new DummySourcesBackend(this));
 }
 
@@ -172,7 +171,7 @@ void DummyBackend::checkForUpdates()
     }
     toggleFetching();
     populate(QStringLiteral("Moar"));
-    QTimer::singleShot(500, this, &DummyBackend::toggleFetching);
+    QTimer::singleShot(15000, this, &DummyBackend::toggleFetching);
     qDebug() << "DummyBackend::checkForUpdates";
 
     Q_EMIT passiveMessage(u"Dummy: Checking for updates"_s);
