@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef DUMMYTEST_H
-#define DUMMYTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -35,5 +34,3 @@ private:
     AbstractResourcesBackend *m_appBackend;
     ResourcesModel *m_model;
 };
-
-#endif // DUMMYTEST_H
