@@ -15,7 +15,7 @@ class PKTransaction : public Transaction
 {
     Q_OBJECT
 public:
-    explicit PKTransaction(const QVector<AbstractResource *> &app, Transaction::Role role);
+    explicit PKTransaction(const QVector<AbstractResource *> &resources, Transaction::Role role);
     PackageKit::Transaction *transaction();
 
     void cancel() override;
@@ -45,6 +45,7 @@ private:
                                const QString &keyFingerprint,
                                const QString &keyTimestamp,
                                PackageKit::Transaction::SigType type);
+    bool isLocal() const;
 
     void trigger(PackageKit::Transaction::TransactionFlags flags);
     QPointer<PackageKit::Transaction> m_trans;
