@@ -52,6 +52,7 @@
 #include "libdiscover_backend_packagekit_debug.h"
 #include "utils.h"
 #include <Category/Category.h>
+#include <Category/CategoryModel.h>
 #include <resources/ResourcesModel.h>
 
 using namespace std::chrono_literals;
@@ -133,18 +134,7 @@ PackageKitBackend::PackageKitBackend(QObject *parent)
     , m_refresher(nullptr)
     , m_isFetching(0)
     , m_reviews(OdrsReviewsBackend::global())
-    , m_reportToDistroAction(
-          new DiscoverAction(u"tools-report-bug-symbolic"_s,
-                             i18nc("@action:button %1 is the distro name", "Report This Issue to %1", AppStreamIntegration::global()->osRelease()->name()),
-                             this))
 {
-    connect(m_reportToDistroAction, &DiscoverAction::triggered, this, [] {
-        const auto url = QUrl(AppStreamIntegration::global()->osRelease()->bugReportUrl());
-        if (!QDesktopServices::openUrl(url)) {
-            qCWarning(LIBDISCOVER_BACKEND_PACKAGEKIT_LOG) << "Failed to open bug report url" << url;
-        }
-    });
-
     QTimer *t = new QTimer(this);
     connect(t, &QTimer::timeout, this, &PackageKitBackend::checkForUpdates);
     t->setInterval(60 * 60 * 1000);
@@ -237,6 +227,28 @@ PackageKitBackend::PackageKitBackend(QObject *parent)
 
     m_globalHints = QStringList() << QStringLiteral("interactive=true") << QStringLiteral("locale=%1").arg(qEnvironmentVariable("LANG"));
     PackageKit::Daemon::global()->setHints(m_globalHints);
+
+    // Hide the drivers category if there's no drivers
+    connect(CategoryModel::global(), &CategoryModel::rootCategoriesChanged, this, [this] {
+        auto driversCategory = CategoryModel::global()->findCategoryByName(QStringLiteral("Hardware Drivers"));
+
+        // Will be null on subsequent runs
+        if (!driversCategory) {
+            return;
+        }
+
+        AbstractResourcesBackend::Filters filter;
+        filter.category = driversCategory;
+        auto stream = search(filter);
+        connect(stream, &ResultsStream::resourcesFound, stream, [stream] {
+            stream->setProperty("foundDrivers", true);
+        });
+        connect(stream, &ResultsStream::destroyed, stream, [stream, driversCategory] {
+            if (!stream->property("foundDrivers").toBool()) {
+                driversCategory->hide();
+            }
+        });
+    });
 }
 
 PackageKitBackend::~PackageKitBackend()
@@ -381,8 +393,6 @@ AppPackageKitResource *PackageKitBackend::addComponent(const AppStream::Componen
 {
     const QStringList pkgNames = component.packageNames();
     Q_ASSERT(!pkgNames.isEmpty());
-    Q_ASSERT(component.kind() != AppStream::Component::KindFirmware);
-
     auto appId = makeAppId(component.id());
     auto resource = qobject_cast<AppPackageKitResource *>(m_packages.packages.value(appId));
     if (!resource) {
@@ -1176,8 +1186,10 @@ InlineMessage *PackageKitBackend::explainDysfunction() const
     if (!PackageKit::Daemon::isRunning()) {
         return new InlineMessage(InlineMessage::Error,
                                  u"run-build-prune-symbolic"_s,
-                                 i18nc("@info", "The background service (PackageKit) stopped unexpectedly. It may have crashed."),
-                                 m_reportToDistroAction);
+                                 i18nc("@info %2 is the name of the operating system",
+                                       "The PackageKit background service stopped unexpectedly.<nl/></nl/>Please <link url='%1'>report this issue to %2</link>",
+                                       KOSRelease().bugReportUrl(),
+                                       KOSRelease().name()));
     }
 
     return AbstractResourcesBackend::explainDysfunction();
