@@ -164,7 +164,8 @@ bool RpmOstreeResource::setNewMajorVersion(const QString &newMajorVersion)
         // Replace the current version in the container tag by the new major version to find
         // the new tag to rebase to. This assumes that container tag names are lowercase.
         QString currentVersion = AppStreamIntegration::global()->osRelease()->versionId();
-        m_nextMajorVersionRef = m_ostreeFormat->tag().replace(currentVersion, newMajorVersion.toLower(), Qt::CaseInsensitive);
+        m_nextMajorVersionRef = m_ostreeFormat->transport() + m_ostreeFormat->repo() + u':'
+            + m_ostreeFormat->tag().replace(currentVersion, newMajorVersion.toLower(), Qt::CaseInsensitive);
         qCDebug(RPMOSTREE_LOG) << "Setting new version to: " << newMajorVersion;
         return true;
     }
@@ -261,7 +262,7 @@ bool RpmOstreeResource::canExecute() const
 
 QVariant RpmOstreeResource::icon() const
 {
-    return QStringLiteral("application-x-rpm");
+    return QStringLiteral("folder-rpm-symbolic");
 }
 
 QString RpmOstreeResource::installedVersion() const
@@ -434,7 +435,7 @@ void RpmOstreeResource::setState(AbstractResource::State state)
 
 QString RpmOstreeResource::sourceIcon() const
 {
-    return QStringLiteral("application-x-rpm");
+    return QStringLiteral("folder-rpm-symbolic");
 }
 
 QStringList RpmOstreeResource::extends() const
@@ -476,17 +477,22 @@ bool RpmOstreeResource::isPending()
     return m_pending;
 }
 
-bool RpmOstreeResource::isClassic()
+bool RpmOstreeResource::isClassic() const
 {
     return m_ostreeFormat->isValid() && m_ostreeFormat->isClassic();
 }
 
-bool RpmOstreeResource::isOCI()
+bool RpmOstreeResource::isOCI() const
 {
     return m_ostreeFormat->isValid() && m_ostreeFormat->isOCI();
 }
 
-QString RpmOstreeResource::OCIUrl()
+bool RpmOstreeResource::isLocalOCI() const
+{
+    return m_ostreeFormat->isValid() && m_ostreeFormat->isOCI() && m_ostreeFormat->isLocalOCI();
+}
+
+QString RpmOstreeResource::OCIUrl() const
 {
     // This will fail on non-remote transports (oci, oci-archive, containers-storage) but that's
     // OK as we can not check for updates in those cases.
