@@ -33,8 +33,9 @@ public:
 
     void trigger()
     {
-        if (m_done)
+        if (m_done) {
             return;
+        }
         m_done = m_function();
         deleteLater();
     }
@@ -82,8 +83,34 @@ static T kFilter(const Q &input, _UnaryOperation op)
 {
     T ret;
     for (const auto &v : input) {
-        if (op(v))
+        if (op(v)) {
             ret += v;
+        }
+    }
+    return ret;
+}
+
+template<typename T, typename Q, typename _UnaryOperation>
+static void kFilterInPlace(Q &input, _UnaryOperation op)
+{
+    for (auto it = input.begin(); it != input.end();) {
+        if (op(*it)) {
+            ++it;
+        } else {
+            it = input.erase(it);
+        }
+    }
+}
+
+template<typename T, typename Q, typename _UnaryOperation>
+static T kFilterTransform(Q &input, _UnaryOperation op)
+{
+    T ret;
+    for (const auto &v : input) {
+        const std::optional<typename T::value_type> result = op(v);
+        if (result.has_value()) {
+            ret += result.value();
+        }
     }
     return ret;
 }
@@ -93,8 +120,9 @@ static int kIndexOf(const Q &list, W func)
 {
     int i = 0;
     for (auto it = list.constBegin(), itEnd = list.constEnd(); it != itEnd; ++it) {
-        if (func(*it))
+        if (func(*it)) {
             return i;
+        }
         ++i;
     }
     return -1;
@@ -117,32 +145,43 @@ static QVector<T> kSetToVector(const QSet<T> &set)
 {
     QVector<T> ret;
     ret.reserve(set.size());
-    for (auto &x : set)
+    for (auto &x : set) {
         ret.append(x);
+    }
     return ret;
 }
+
 template<typename T>
 static QList<T> kSetToList(const QSet<T> &set)
 {
     QList<T> ret;
     ret.reserve(set.size());
-    for (auto &x : set)
+    for (auto &x : set) {
         ret.append(x);
+    }
     return ret;
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-template<typename T>
-static QSet<T> kToSet(const QVector<T> &set)
-{
-    return QSet<T>(set.begin(), set.end());
-}
-#endif
+
 template<typename T>
 static QSet<T> kToSet(const QList<T> &set)
 {
     return QSet<T>(set.begin(), set.end());
 }
 
+template<typename T>
+static void kRemoveDuplicates(QList<T> &input)
+{
+    QSet<T> ret;
+    for (auto it = input.begin(); it != input.end();) {
+        if (!ret.contains(*it)) {
+            ret << *it;
+            ++it;
+        } else {
+            it = input.erase(it);
+        }
+    }
+}
+
 class ElapsedDebug : private QElapsedTimer
 {
 public:
@@ -169,3 +208,26 @@ inline void swap(QJsonValueRef v1, QJsonValueRef v2)
     v1 = QJsonValue(v2);
     v2 = temp;
 }
+
+template<typename T>
+class KeyValueRange
+{
+public:
+    KeyValueRange(T &data)
+        : m_data{data}
+    {
+    }
+
+    auto begin()
+    {
+        return m_data.keyValueBegin();
+    }
+
+    auto end()
+    {
+        return m_data.keyValueEnd();
+    }
+
+private:
+    T &m_data;
+};
